==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Dana operacja jest nieprawidłowa",
    "The given regular expression is invalid" : "Podane wyrażenie regularne jest błędne",
    "The given file size is invalid" : "Podany rozmiar pliku jest nieprawidłowy",
    "The given tag id is invalid" : "Podane id etykiety jest nieprawidłowe",
    "The given IP range is invalid" : "Podany zakres adresów IP jest nieprawidłowy",
    "The given IP range is not valid for IPv4" : "Podany zakres adresów IP jest nieprawidłowy dla IPv4",
    "The given IP range is not valid for IPv6" : "Podany zakres adresów IP jest nieprawidłowy dla IPv6",
    "The given time span is invalid" : "Podany przedział czasowy jest nieprawidłowy",
    "The given start time is invalid" : "Podany czas rozpoczęcia jest nieprawidłowy",
    "The given end time is invalid" : "Podany czas zakończenia jest nieprawidłowy",
    "The given group does not exist" : "Podana grupa nie istnieje",
    "File" : "Plik",
    "File created" : "Plik utworzony",
    "File updated" : "Plik zaktualizowany",
    "File renamed" : "Nazwa pliku zmieniona",
    "File deleted" : "Plik usunięty",
    "File accessed" : "Plik udostępniony",
    "File copied" : "Plik skopiowany",
    "Tag assigned" : "Etykieta przypisana",
    "Operation #%s does not exist" : "Operacja do wykonania #%s nie istnieje",
    "Entity %s does not exist" : "Obiekt %s nie istnieje",
    "Entity %s is invalid" : "Obiekt %s jest nieprawidłowy",
    "No events are chosen." : "Nie wybrano żadnych wydarzeń.",
    "Entity %s has no event %s" : "Obiekt %s nie ma zdarzenia %s",
    "Operation %s does not exist" : "Operacja do wykonania %s nie istnieje",
    "Operation %s is invalid" : "Operacja %s jest nieprawidłowa",
    "Check %s does not exist" : "Sprawdź, czy %s nie istnieje",
    "Check %s is invalid" : "Sprawdź, czy %s jest nieprawidłowy",
    "Check %s is not allowed with this entity" : "Sprawdzenie %s jest niedozwolone w tym obiekcie",
    "Check #%s does not exist" : "Sprawdź, czy #%s nie istnieje",
    "Check %s is invalid or does not exist" : "Sprawdź, czy %s jest nieprawidłowa lub nie istnieje",
    "Workflows" : "Workflows",
    "Nextcloud workflow engine" : "Silnik Nextcloud workflow",
    "Select a filter" : "Wybierz filtr",
    "Select a comparator" : "Wybierz komparator",
    "Select a file type" : "Wybierz typ pliku",
    "e.g. httpd/unix-directory" : "np. httpd/unix-directory",
    "Images" : "Obrazy",
    "Office documents" : "Dokumenty biurowe",
    "PDF documents" : "Dokumenty PDF",
    "Custom mimetype" : "Niestandardowy typ MIME",
    "Select a tag" : "Wybierz etykietę",
    "No results" : "Brak wyników",
    "%s (invisible)" : "%s (niewidoczny)",
    "%s (restricted)" : "%s (ograniczony)",
    "Please enter a valid time span" : "Podaj prawidłowy przedział czasu",
    "Select a request URL" : "Wybierz adres URL żądania",
    "Predefined URLs" : "Przedefiniowanie URLs",
    "Files WebDAV" : "Pliki WebDAV",
    "Others" : "Inne",
    "Custom URL" : "Niestandardowy adres URL",
    "Select a user agent" : "Wybierz klienta użytkownika",
    "Android client" : "Klient Android",
    "iOS client" : "Klient iOS",
    "Desktop client" : "Klient na komputer",
    "Thunderbird & Outlook addons" : "Dodatki Thunderbird i Outlook",
    "Custom user agent" : "Niestandardowy klient użytkownika",
    "When" : "Kiedy",
    "and" : "i",
    "Cancel" : "Anuluj",
    "Delete" : "Usuń",
    "The configuration is invalid" : "Konfiguracja jest nieprawidłowa",
    "Show less" : "Pokaż mniej",
    "Show more" : "Pokaż więcej",
    "File name" : "Nazwa pliku",
    "is" : "jest",
    "is not" : "nie jest",
    "matches" : "pasuje",
    "does not match" : "nie pasuje",
    "File MIME type" : "Typy plików MIME",
    "File size (upload)" : "Rozmiar pliku (wczytywanego)",
    "less" : "mniejszy",
    "less or equals" : "mniejszy lub równy",
    "greater or equals" : "większy lub równy",
    "greater" : "większy",
    "Request remote address" : "Uzyskaj zdalny adres",
    "matches IPv4" : "pasuje IPv4",
    "does not match IPv4" : "nie pasuje IPv4",
    "matches IPv6" : "pasuje IPv6",
    "does not match IPv6" : "nie pasuje IPv6",
    "File system tag" : "Etykieta systemu plików",
    "is tagged with" : "jest oznaczony",
    "is not tagged with" : "Nie jest oznaczony",
    "Request URL" : "Żądanie URL",
    "Request time" : "Czas odpowiedzi",
    "between" : "pomiędzy",
    "not between" : "nie pomiędzy",
    "Request user agent" : "Żądanie agenta użytkownika",
    "User group membership" : "Członkostwo grupy użytkownika",
    "is member of" : "jest członkiem w",
    "is not member of" : "nie jest członkiem w",
    "Short rule description" : "Krótki opis reguły",
    "Add rule" : "Dodaj regułę",
    "Reset" : "Zresetuj",
    "Save" : "Zapisz",
    "Saving…" : "Zapisywanie…",
    "Group list is empty" : "Lista grup jest pusta",
    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
    "Saved" : "Zapisano",
    "Saving failed:" : "Nieudany zapis:",
    "Add rule group" : "Dodaj grupę reguł",
    "Example: {placeholder}" : "Przykład: {placeholder}",
    "Select tag…" : "Wybierz etykietę…",
    "Start" : "Start",
    "End" : "Koniec",
    "Select timezone…" : "Wybierz strefę czasową…",
    "Sync clients" : "Klienci synchronizacji",
    "Workflow" : "Workflow",
    "Files workflow engine" : "Pliki silnika workflow",
    "Open documentation" : "Otwórz dokumentację",
    "Loading…" : "Wczytywanie…",
    "Tag management" : "Zarządzanie etykietami"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Dana operacja jest nieprawidłowa",
    "The given regular expression is invalid" : "Podane wyrażenie regularne jest błędne",
    "The given file size is invalid" : "Podany rozmiar pliku jest nieprawidłowy",
    "The given tag id is invalid" : "Podane id etykiety jest nieprawidłowe",
    "The given IP range is invalid" : "Podany zakres adresów IP jest nieprawidłowy",
    "The given IP range is not valid for IPv4" : "Podany zakres adresów IP jest nieprawidłowy dla IPv4",
    "The given IP range is not valid for IPv6" : "Podany zakres adresów IP jest nieprawidłowy dla IPv6",
    "The given time span is invalid" : "Podany przedział czasowy jest nieprawidłowy",
    "The given start time is invalid" : "Podany czas rozpoczęcia jest nieprawidłowy",
    "The given end time is invalid" : "Podany czas zakończenia jest nieprawidłowy",
    "The given group does not exist" : "Podana grupa nie istnieje",
    "File" : "Plik",
    "File created" : "Plik utworzony",
    "File updated" : "Plik zaktualizowany",
    "File renamed" : "Nazwa pliku zmieniona",
    "File deleted" : "Plik usunięty",
    "File accessed" : "Plik udostępniony",
    "File copied" : "Plik skopiowany",
    "Tag assigned" : "Etykieta przypisana",
    "Someone" : "Ktoś",
    "%s created %s" : "%s utworzył %s",
    "%s modified %s" : "%s zmodyfikował %s",
    "%s deleted %s" : "%s usunął %s",
    "%s accessed %s" : "%s udostępnił %s",
    "%s renamed %s" : "%s zmienił %s",
    "%s copied %s" : "%s skopiował %s",
    "%s assigned %s to %s" : "%s przypisał %s do %s",
    "Operation #%s does not exist" : "Operacja do wykonania #%s nie istnieje",
    "Entity %s does not exist" : "Obiekt %s nie istnieje",
    "Entity %s is invalid" : "Obiekt %s jest nieprawidłowy",
    "No events are chosen." : "Nie wybrano żadnych wydarzeń.",
    "Entity %s has no event %s" : "Obiekt %s nie ma zdarzenia %s",
    "Operation %s does not exist" : "Operacja do wykonania %s nie istnieje",
    "Operation %s is invalid" : "Operacja %s jest nieprawidłowa",
    "Check %s does not exist" : "Sprawdź, czy %s nie istnieje",
    "Check %s is invalid" : "Sprawdź, czy %s jest nieprawidłowy",
    "Check %s is not allowed with this entity" : "Sprawdzenie %s jest niedozwolone w tym obiekcie",
    "Check #%s does not exist" : "Sprawdź, czy #%s nie istnieje",
    "Check %s is invalid or does not exist" : "Sprawdź, czy %s jest nieprawidłowa lub nie istnieje",
    "Flow" : "Przepływ",
    "Nextcloud workflow engine" : "Silnik Nextcloud workflow",
    "Select a filter" : "Wybierz filtr",
    "Select a comparator" : "Wybierz komparator",
    "Select a file type" : "Wybierz typ pliku",
    "e.g. httpd/unix-directory" : "np. httpd/unix-directory",
    "Images" : "Obrazy",
    "Office documents" : "Dokumenty biurowe",
    "PDF documents" : "Dokumenty PDF",
    "Custom mimetype" : "Niestandardowy typ MIME",
    "Select a tag" : "Wybierz etykietę",
    "No results" : "Brak wyników",
    "%s (invisible)" : "%s (niewidoczny)",
    "%s (restricted)" : "%s (ograniczony)",
    "Please enter a valid time span" : "Podaj prawidłowy przedział czasu",
    "Select a request URL" : "Wybierz adres URL żądania",
    "Predefined URLs" : "Przedefiniowanie URLs",
    "Files WebDAV" : "Pliki WebDAV",
    "Others" : "Inne",
    "Custom URL" : "Niestandardowy adres URL",
    "Select a user agent" : "Wybierz klienta użytkownika",
    "Android client" : "Klient Android",
    "iOS client" : "Klient iOS",
    "Desktop client" : "Klient na komputer",
    "Thunderbird & Outlook addons" : "Dodatki Thunderbird i Outlook",
    "Custom user agent" : "Niestandardowy klient użytkownika",
    "Add new flow" : "Dodaj nowy przepływ",
    "When" : "Kiedy",
    "and" : "i",
    "Cancel" : "Anuluj",
    "Delete" : "Usuń",
    "The configuration is invalid" : "Konfiguracja jest nieprawidłowa",
    "Active" : "Aktywne",
    "Save" : "Zapisz",
    "Available flows" : "Dostępne przepływy",
    "For details on how to write your own flow, check out the development documentation." : "Aby uzyskać szczegółowe informacje na temat pisania własnego przepływu, zapoznaj się z dokumentacją programistyczną.",
    "More flows" : "Więcej przepływów",
    "Browse the app store" : "Przeglądaj sklep z aplikacjami",
    "Show less" : "Pokaż mniej",
    "Show more" : "Pokaż więcej",
    "Configured flows" : "Skonfigurowane przepływy",
    "Your flows" : "Twoje przepływy",
    "File name" : "Nazwa pliku",
    "is" : "jest",
    "is not" : "nie jest",
    "matches" : "pasuje",
    "does not match" : "nie pasuje",
    "File MIME type" : "Typy plików MIME",
    "File size (upload)" : "Rozmiar pliku (wczytywanego)",
    "less" : "mniejszy",
    "less or equals" : "mniejszy lub równy",
    "greater or equals" : "większy lub równy",
    "greater" : "większy",
    "Request remote address" : "Uzyskaj zdalny adres",
    "matches IPv4" : "pasuje IPv4",
    "does not match IPv4" : "nie pasuje IPv4",
    "matches IPv6" : "pasuje IPv6",
    "does not match IPv6" : "nie pasuje IPv6",
    "File system tag" : "Etykieta systemu plików",
    "is tagged with" : "jest oznaczony",
    "is not tagged with" : "Nie jest oznaczony",
    "Request URL" : "Żądanie URL",
    "Request time" : "Czas odpowiedzi",
    "between" : "pomiędzy",
    "not between" : "nie pomiędzy",
    "Request user agent" : "Żądanie agenta użytkownika",
    "User group membership" : "Członkostwo grupy użytkownika",
    "is member of" : "jest członkiem w",
    "is not member of" : "nie jest członkiem w",
    "Short rule description" : "Krótki opis reguły",
    "Add rule" : "Dodaj regułę",
    "Reset" : "Zresetuj",
    "Saving…" : "Zapisywanie…",
    "Group list is empty" : "Lista grup jest pusta",
    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
    "Saved" : "Zapisano",
    "Saving failed:" : "Nieudany zapis:",
    "Add rule group" : "Dodaj grupę reguł",
    "Example: {placeholder}" : "Przykład: {placeholder}",
    "Select tag…" : "Wybierz etykietę…",
    "Start" : "Start",
    "End" : "Koniec",
    "Select timezone…" : "Wybierz strefę czasową…",
    "Sync clients" : "Klienci synchronizacji",
    "Workflow" : "Workflow",
    "Files workflow engine" : "Pliki silnika workflow",
    "Open documentation" : "Otwórz dokumentację",
    "Loading…" : "Wczytywanie…",
    "Tag management" : "Zarządzanie etykietami"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
